# SUI
SUI(Some Useful Implementations) is a peckage including selected implementations apropos machine learning, deep learning, and reinforcement learning algorithms.

## 0. Why SUI?
SUI is a framework integrated a spate of sound and applicable models apropos machine learning, deep learning, and reinforcement learning based on top-notch publications and dependable open-source frameworks. In SUI, there are models being ubiquitous in industrial projects. For all some of these algorithms might be moth-eaten and obsolete as a bromide, they are still not futile or feckless. Every model can be a meet solution for a felicitous scenario.

## 1. Install
Use pip to install SUI is highly recommended. Open your terminal and input:
```bash
pip install sui
```
Then, open python to import SUI and test it by:
```python
import sui

print(sui.my_dear)
```

## 2. Get Started
